CantSim = LibStub("AceAddon-3.0"):NewAddon("CantSim", "AceConsole-3.0")

local addonName = "Can't Sim"
local stats = {}
local atonementHealing = 72
local debug = false
function CantSim:GetCharacterStats()
    stats["critRating"] = GetCombatRating(9) 
    stats["critPercent"] = GetCritChance()
    stats["hasteRating"] = GetCombatRating(18)
    stats["hastePercent"] = GetHaste()
    stats["masteryRating"] = GetCombatRating(26)
    stats["masteryPercent"] = stats.masteryRating / 250
    stats["versatilityRating"] = GetCombatRating(29)
    stats.versatilityPercent = stats.versatilityRating / 475
    stats.effectiveILvl = select(1, GetDetailedItemLevelInfo(GetInventoryItemLink("player", 16)))
    stats.classInfo = UnitClass("player")
    stats.currentSpec = GetSpecialization()
    stats.currentSpecName = stats.currentSpec and select(2, GetSpecializationInfo(stats.currentSpec)) or "None"
end

function CantSim:GetPawnString()
    CantSim:GetCharacterStats()
    if stats.classInfo == "Priest" then
        if stats.currentSpecName == "Discipline" then
            leechModifier = 1
            stats.intRating = UnitStat("player", 4)
            stats.intPawn = 1000/((stats.intRating/100)/1.05)
            stats.critPawn = 1000*leechModifier/400/((stats.critPercent/100 * leechModifier) + 1)
            stats.masteryPawn = 1000*(1/250/(1+(stats.masteryPercent + 12.8)/100)* atonementHealing/100)
            stats.versatilityPawn = 1000 * (1/475/(1+stats.versatilityPercent/100))
            stats.maxResult = math.max(stats.critPawn, stats.masteryPawn, stats.versatilityPawn)
            stats.hastePawn = stats.maxResult * 1.25 / (1 + (stats.hastePercent/100))
            pawnString = "( Pawn: v1: \"Disc (Can't Sim)\": Intellect="..stats.intPawn..", Versatility="..stats.versatilityPawn..", HasteRating="..stats.hastePawn..", MasteryRating="..stats.masteryPawn..", CritRating="..stats.critPawn..", Leech=2.17)"
        end
    else 
        pawnString = "Your class/spec is not supported yet. Feel free to PM me @Drizz#2038 on Discord to get your spec started."
    end
    if debug then 
        for k,v in pairs(stats) do print(k,v) end
        print(pawnString)
    end
    LibStub("AceConfigDialog-3.0"):Open(addonName)
end

function CantSim:Reset()
    stats = {}
    pawnString = ""
    atonementHealing = 72
end

function CantSim:UpdateAtonementHealing(number)
    atonementHealing = number
end

local options = {
    name = addonName,
    handler = CantSim,
    type = 'group',
    args = {
        get = {
            type = "execute",
            name = "Get Pawn",
            desc = "Gets your pawn string for your spec",
            func = "GetPawnString",
            order = 1,
            width = "half"
        },
        reset = {
            type = "execute",
            name = "Reset",
            desc = "Resets your pawn string",
            func = "Reset",
            order = 2,
            width = "half"
        },
        characterInfo = {
            type = "group",
            order = 3,
            name = "Character Information",
            inline = true,
            args = {
                atonementPercent = {
                    order = 1,
                    type = "range",
                    name = "Atonement Healing Percentage",
                    desc = "Percent of healing that comes from Atonement",
                    min = 1, max = 100, step = 1,
                    get = function() return atonementHealing end,
                    set = function(info, value) CantSim:UpdateAtonementHealing(value) end
                },
                pawn = {
                    type = "input",
                    name = "Pawn String",
                    desc = "Displays your pawn string",
                    multiline = 5,
                    width = "full",
                    get = function() return pawnString end,
                    cmdHidden = true
                },

            }
        }    
    },
}

function CantSim:OnInitialize()
    CantSim:GetCharacterStats()
    LibStub("AceConfig-3.0"):RegisterOptionsTable(addonName, options, "cs", "cantsim")
    LibStub("AceConfigDialog-3.0"):AddToBlizOptions(addonName, addonName)
end